@@ -35,8 +35,9 @@ class PaymentResource(BaseResource):
         else:
             return UnitError.from_json_api(response.json())
 
-    def list(self, offset: int = 0, limit: int = 100) -> Union[UnitResponse[List[PaymentDTO]], UnitError]:
-        response = super().get(self.resource, {"page[limit]": limit, "page[offset]": offset})
+    def list(self, params: ListPaymentParams = None) -> Union[UnitResponse[List[PaymentDTO]], UnitError]:
+        params = params or ListPaymentParams()
+        response = super().get(self.resource, params.to_dict())
         if response.status_code == 200:
             data = response.json().get("data")
             included = response.json().get("included")
