@@ -2,22 +2,42 @@ import json
 from typing import TypeVar, Generic, Union, Optional, Literal, List, Dict
 from datetime import datetime, date
 
+def to_camel_case(snake_str):
+    components = snake_str.lstrip('_').split('_')
+    # We capitalize the first letter of each component except the first one
+    # with the 'title' method and join them together.
+    return components[0] + ''.join(x.title() for x in components[1:])
 
-class Relationship(object):
+class UnitDTO(object):
+    def to_dict(self):
+        if type(self) is dict:
+            return dto
+        else:
+            v = vars(self)
+            return dict((to_camel_case(k), val) for k, val in v.items() if val is not None)
+
+
+class Relationship(UnitDTO):
     def __init__(self, _type: str, _id: str):
         self.type = _type
         self.id = _id
 
-    def to_dict(self):
-        return {"type": self.type, "id": self.id}
+    def to_dict(self, nested: Optional[bool] = True):
+        if nested:
+            return {"data": {"type": self.type, "id": self.id}}
+        else:
+            return {"type": self.type, "id": self.id}
 
 
 T = TypeVar('T')
 
-class RelationshipArray(Generic[T]):
+class RelationshipArray(Generic[T], UnitDTO):
     def __init__(self, l: List[T]):
         self.relationships = l
 
+    def to_dict(self):
+        return {"data": list(map(lambda r: r.to_dict(False), self.relationships))}
+
 
 class UnitResponse(Generic[T]):
     def __init__(self, data: Union[T, List[T]], included):
@@ -37,13 +57,17 @@ class UnitParams(object):
     def to_dict(self) -> Dict:
         pass
 
-class RawUnitObject(object):
+class RawUnitObject(UnitDTO):
     def __init__(self, _id, _type, attributes, relationships):
         self.id = _id
         self.type = _type
         self.attributes = attributes
         self.relationships = relationships
 
+    def to_dict(self):
+        v = vars(self.attributes)
+        return dict((to_camel_case(k), val) for k, val in v.items() if val is not None)
+
 class UnitErrorPayload(object):
     def __init__(self, title: str, status: str, detail: Optional[str] = None, details: Optional[str] = None,
                  source: Optional[Dict] = None, code: Optional[str] = None):
@@ -82,7 +106,7 @@ Status = Literal["Approved", "Denied", "PendingReview"]
 Title = Literal["CEO", "COO", "CFO", "President"]
 EntityType = Literal["Corporation", "LLC", "Partnership"]
 
-class FullName(object):
+class FullName(UnitDTO):
     def __init__(self, first: str, last: str):
         self.first = first
         self.last = last
@@ -93,7 +117,7 @@ class FullName(object):
 
 
 # todo: Alex - use typing.Literal for multi accepted values (e.g country)
-class Address(object):
+class Address(UnitDTO):
     def __init__(self, street: str, city: str, state: str, postal_code: str, country: str,
                  street2: Optional[str] = None):
         self.street = street
@@ -109,7 +133,7 @@ class Address(object):
                 data.get("postalCode"), data.get("country"), data.get("street2", None))
 
 
-class Phone(object):
+class Phone(UnitDTO):
     def __init__(self, country_code: str, number: str):
         self.country_code = country_code
         self.number = number
@@ -119,7 +143,7 @@ class Phone(object):
         return Phone(data.get("countryCode"), data.get("number"))
 
 
-class BusinessContact(object):
+class BusinessContact(UnitDTO):
     def __init__(self, full_name: FullName, email: str, phone: Phone):
         self.full_name = full_name
         self.email = email
@@ -130,7 +154,7 @@ class BusinessContact(object):
         return BusinessContact(FullName.from_json_api(data.get("fullName")), data.get("email"), Phone.from_json_api(data.get("phone")))
 
 
-class Officer(object):
+class Officer(UnitDTO):
     def __init__(self, full_name: FullName, date_of_birth: date, address: Address, phone: Phone, email: str,
                  status: Optional[Status] = None, title: Optional[Title] = None, ssn: Optional[str] = None,
                  passport: Optional[str] = None, nationality: Optional[str] = None):
@@ -152,7 +176,7 @@ class Officer(object):
                 data.get("nationality"))
 
 
-class BeneficialOwner(object):
+class BeneficialOwner(UnitDTO):
     def __init__(self, full_name: FullName, date_of_birth: date, address: Address, phone: Phone, email: str,
                  status: Optional[Status] = None, ssn: Optional[str] = None, passport: Optional[str] = None,
                  nationality: Optional[str] = None, percentage: Optional[int] = None):
@@ -177,7 +201,7 @@ class BeneficialOwner(object):
         return beneficial_owners
 
 
-class AuthorizedUser(object):
+class AuthorizedUser(UnitDTO):
     def __init__(self, full_name: FullName, email: str, phone: Phone, jwt_subject: Optional[str]):
         self.full_name = full_name
         self.email = email
@@ -199,7 +223,7 @@ class AuthorizedUser(object):
         return [AuthorizedUser(FullName.from_json_api(d.get("fullName")), d.get("email"),
                               Phone.from_json_api(d.get("phone")), d.get("jwtSubject")) for d in data]
 
-class WireCounterparty(object):
+class WireCounterparty(UnitDTO):
     def __init__(self, routing_number: str, account_number: str, name: str, address: Address):
         self.routing_number = routing_number
         self.account_number = account_number
@@ -211,7 +235,7 @@ class WireCounterparty(object):
         return WireCounterparty(data["routingNumber"], data["accountNumber"], data["name"],
                                 Address.from_json_api(data["address"]))
 
-class Counterparty(object):
+class Counterparty(UnitDTO):
     def __init__(self, routing_number: str, account_number: str, account_type: str, name: str):
         self.routing_number = routing_number
         self.account_number = account_number
@@ -222,8 +246,8 @@ class Counterparty(object):
     def from_json_api(data: Dict):
         return Counterparty(data["routingNumber"], data["accountNumber"], data["accountType"], data["name"])
 
-class Coordinates(object):
-    def __init__(self, longitude: int, latitude: int):
+class Coordinates(UnitDTO):
+    def __init__(self, longitude: float, latitude: float):
         self.longitude = longitude
         self.latitude = latitude
 
@@ -232,7 +256,7 @@ class Coordinates(object):
         return Coordinates(data["longitude"], data["latitude"])
 
 
-class Merchant(object):
+class Merchant(UnitDTO):
     def __init__(self, name: str, type: int, category: str, location: Optional[str]):
         self.name = name
         self.type = type
@@ -243,7 +267,7 @@ class Merchant(object):
     def from_json_api(data: Dict):
         return Merchant(data["name"], data["type"], data["category"], data.get("location"))
 
-class CardLevelLimits(object):
+class CardLevelLimits(UnitDTO):
     def __init__(self, daily_withdrawal: int, daily_purchase: int, monthly_withdrawal: int, monthly_purchase: int):
         self.daily_withdrawal = daily_withdrawal
         self.daily_purchase = daily_purchase
@@ -255,7 +279,7 @@ class CardLevelLimits(object):
         return CardLevelLimits(data["dailyWithdrawal"], data["dailyPurchase"], data["monthlyWithdrawal"],
                       data["monthlyPurchase"])
 
-class CardTotals(object):
+class CardTotals(UnitDTO):
     def __init__(self, withdrawals: int, deposits: int, purchases: int):
         self.withdrawals = withdrawals
         self.deposits = deposits
@@ -266,7 +290,7 @@ class CardTotals(object):
         return CardTotals(data["withdrawals"], data["deposits"], data["purchases"])
 
 
-class DeviceFingerprint(object):
+class DeviceFingerprint(UnitDTO):
     def __init__(self, value: str, provider: str = "iovation"):
         self.value = value
         self.provider = provider
