@@ -6,9 +6,12 @@ ApplicationStatus = Literal["Approved", "Denied", "Pending", "PendingReview"]
 
 DocumentType = Literal["IdDocument", "Passport", "AddressVerification", "CertificateOfIncorporation",
                        "EmployerIdentificationNumberConfirmation"]
+
 ReasonCode = Literal["PoorQuality", "NameMismatch", "SSNMismatch", "AddressMismatch", "DOBMismatch", "ExpiredId",
                      "EINMismatch", "StateMismatch", "Other"]
 
+ApplicationTypes = Literal["individualApplication", "businessApplication"]
+
 class IndividualApplicationDTO(object):
     def __init__(self, id: str, created_at: datetime, full_name: FullName, address: Address, date_of_birth: date,
                  email: str, phone: Phone, status: ApplicationStatus, ssn: Optional[str], message: Optional[str],
@@ -69,7 +72,7 @@ class CreateIndividualApplicationRequest(UnitRequest):
     def __init__(self, full_name: FullName, date_of_birth: date, address: Address, email: str, phone: Phone,
                  ip: str = None, ein: str = None, dba: str = None, sole_proprietorship: bool = None,
                  passport: str = None, nationality: str = None, ssn = None,
-                 device_fingerprints: Optional[List[DeviceFingerprint]] = None, idempotency_key: str = None, 
+                 device_fingerprints: Optional[List[DeviceFingerprint]] = None, idempotency_key: str = None,
                  tags: Optional[Dict[str, str]] = None):
         self.full_name = full_name
         self.date_of_birth = date_of_birth
@@ -129,7 +132,7 @@ class CreateIndividualApplicationRequest(UnitRequest):
             payload["data"]["attributes"]["deviceFingerprints"] = [e.to_json_api() for e in self.device_fingerprints]
 
         if self.tags:
-            payload["data"]["attributes"]["tags"] = self.tags 
+            payload["data"]["attributes"]["tags"] = self.tags
 
         return payload
 
@@ -241,3 +244,27 @@ class ListApplicationParams(UnitParams):
         if self.sort:
             parameters["sort"] = self.sort
         return parameters
+
+class PatchApplicationRequest(UnitRequest):
+    def __init__(self, application_id: str, type: ApplicationTypes = "individualApplication",
+                 tags: Optional[Dict[str, str]] = None):
+        self.application_id = application_id
+        self.type = type
+        self.tags = tags
+
+    def to_json_api(self) -> Dict:
+        payload = {
+            "data": {
+                "type": self.type,
+                "attributes": {}
+            }
+        }
+
+        if self.tags:
+            payload["data"]["attributes"]["tags"] = self.tags
+
+        return payload
+
+    def __repr__(self):
+        json.dumps(self.to_json_api())
+
